# pelican-hyde

The pelican-hyde is a [Pelican](https://github.com/getpelican) theme inspired on the beautiful [Hyde](http://hyde.getpoole.com/) Jekyll theme

You can see a live demo [here](http://jvanz.github.io/)


![Screenshot](screenshot.png)
